==> igniteui-webcomponents-layouts-4.7.2-beta.0.tgz: package/esm5/lib/igc-tool-action-separator-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { getAllPropertyNames, toSpinal, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionSeparatorComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionSeparatorComponent, _super);
    function IgcToolActionSeparatorComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionSeparatorComponent.prototype.createImplementation = function () {
        return new ToolActionSeparator();
    };
    Object.defineProperty(IgcToolActionSeparatorComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionSeparatorComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionSeparatorComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionSeparatorComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent == null) {
                var names = getAllPropertyNames(IgcToolActionSeparatorComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = names;
            }
            return IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionSeparatorComponent.register = function () {
        if (!IgcToolActionSeparatorComponent._isElementRegistered) {
            IgcToolActionSeparatorComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionSeparatorComponent.htmlTagName, IgcToolActionSeparatorComponent);
        }
    };
    Object.defineProperty(IgcToolActionSeparatorComponent.prototype, "size", {
        /**
         * Gets or sets the size of the separator.
        */
        get: function () {
            return this.i.e9;
        },
        set: function (v) {
            this.i.e9 = +v;
            this._a("size", this.i.e9);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionSeparatorComponent.prototype, "isGroupHeaderSeparator", {
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get: function () {
            return this.i.e7;
        },
        set: function (v) {
            this.i.e7 = ensureBool(v);
            this._a("isGroupHeaderSeparator", this.i.e7);
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionSeparatorComponent.prototype.fromInfo = function (info) {
        this.i.dt(info);
    };
    IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = null;
    IgcToolActionSeparatorComponent.htmlTagName = "igc-tool-action-separator";
    IgcToolActionSeparatorComponent._isElementRegistered = false;
    return IgcToolActionSeparatorComponent;
}(IgcToolActionComponent));
export { IgcToolActionSeparatorComponent };

==> igniteui-webcomponents-layouts-4.8.1-beta.0.tgz: package/esm5/lib/igc-tool-action-separator-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionSeparator } from "./ToolActionSeparator";
import { getAllPropertyNames, toSpinal, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionSeparatorComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionSeparatorComponent, _super);
    function IgcToolActionSeparatorComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionSeparatorComponent.prototype.createImplementation = function () {
        return new ToolActionSeparator();
    };
    Object.defineProperty(IgcToolActionSeparatorComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionSeparatorComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionSeparatorComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionSeparatorComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent == null) {
                var names = getAllPropertyNames(IgcToolActionSeparatorComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = names;
            }
            return IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionSeparatorComponent.register = function () {
        if (!IgcToolActionSeparatorComponent._isElementRegistered) {
            IgcToolActionSeparatorComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionSeparatorComponent.htmlTagName, IgcToolActionSeparatorComponent);
        }
    };
    Object.defineProperty(IgcToolActionSeparatorComponent.prototype, "size", {
        /**
         * Gets or sets the size of the separator.
        */
        get: function () {
            return this.i.f9;
        },
        set: function (v) {
            this.i.f9 = +v;
            this._a("size", this.i.f9);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionSeparatorComponent.prototype, "isGroupHeaderSeparator", {
        /**
         * Gets or sets whether to use group header styling or regular styling on this separator.
        */
        get: function () {
            return this.i.f7;
        },
        set: function (v) {
            this.i.f7 = ensureBool(v);
            this._a("isGroupHeaderSeparator", this.i.f7);
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionSeparatorComponent.prototype.fromInfo = function (info) {
        this.i.ej(info);
    };
    IgcToolActionSeparatorComponent._observedAttributesIgcToolActionSeparatorComponent = null;
    IgcToolActionSeparatorComponent.htmlTagName = "igc-tool-action-separator";
    IgcToolActionSeparatorComponent._isElementRegistered = false;
    return IgcToolActionSeparatorComponent;
}(IgcToolActionComponent));
export { IgcToolActionSeparatorComponent };
